==> zio-aws-redshift_2.13-5.17.146.1-sources.jar: zio/aws/redshift/model/ModifySnapshotCopyRetentionPeriodResponse.scala <==
package zio.aws.redshift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ModifySnapshotCopyRetentionPeriodResponse(
    cluster: Option[zio.aws.redshift.model.Cluster] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.ModifySnapshotCopyRetentionPeriodResponse = {
    import ModifySnapshotCopyRetentionPeriodResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.ModifySnapshotCopyRetentionPeriodResponse
      .builder()
      .optionallyWith(cluster.map(value => value.buildAwsValue()))(_.cluster)
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.ModifySnapshotCopyRetentionPeriodResponse.ReadOnly =
    zio.aws.redshift.model.ModifySnapshotCopyRetentionPeriodResponse
      .wrap(buildAwsValue())
}
object ModifySnapshotCopyRetentionPeriodResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.ModifySnapshotCopyRetentionPeriodResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.redshift.model.ModifySnapshotCopyRetentionPeriodResponse =
      zio.aws.redshift.model.ModifySnapshotCopyRetentionPeriodResponse(
        cluster.map(value => value.asEditable)
      )
    def cluster: Option[zio.aws.redshift.model.Cluster.ReadOnly]
    def getCluster
        : ZIO[Any, AwsError, zio.aws.redshift.model.Cluster.ReadOnly] =
      AwsError.unwrapOptionField("cluster", cluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.ModifySnapshotCopyRetentionPeriodResponse
  ) extends zio.aws.redshift.model.ModifySnapshotCopyRetentionPeriodResponse.ReadOnly {
    override val cluster: Option[zio.aws.redshift.model.Cluster.ReadOnly] =
      scala
        .Option(impl.cluster())
        .map(value => zio.aws.redshift.model.Cluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.ModifySnapshotCopyRetentionPeriodResponse
  ): zio.aws.redshift.model.ModifySnapshotCopyRetentionPeriodResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-redshift_2.13-5.17.212.1-sources.jar: zio/aws/redshift/model/ModifySnapshotCopyRetentionPeriodResponse.scala <==
package zio.aws.redshift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifySnapshotCopyRetentionPeriodResponse(
    cluster: Optional[zio.aws.redshift.model.Cluster] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.ModifySnapshotCopyRetentionPeriodResponse = {
    import ModifySnapshotCopyRetentionPeriodResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.ModifySnapshotCopyRetentionPeriodResponse
      .builder()
      .optionallyWith(cluster.map(value => value.buildAwsValue()))(_.cluster)
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.ModifySnapshotCopyRetentionPeriodResponse.ReadOnly =
    zio.aws.redshift.model.ModifySnapshotCopyRetentionPeriodResponse
      .wrap(buildAwsValue())
}
object ModifySnapshotCopyRetentionPeriodResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.ModifySnapshotCopyRetentionPeriodResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.redshift.model.ModifySnapshotCopyRetentionPeriodResponse =
      zio.aws.redshift.model.ModifySnapshotCopyRetentionPeriodResponse(
        cluster.map(value => value.asEditable)
      )
    def cluster: Optional[zio.aws.redshift.model.Cluster.ReadOnly]
    def getCluster
        : ZIO[Any, AwsError, zio.aws.redshift.model.Cluster.ReadOnly] =
      AwsError.unwrapOptionField("cluster", cluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.ModifySnapshotCopyRetentionPeriodResponse
  ) extends zio.aws.redshift.model.ModifySnapshotCopyRetentionPeriodResponse.ReadOnly {
    override val cluster: Optional[zio.aws.redshift.model.Cluster.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cluster())
        .map(value => zio.aws.redshift.model.Cluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.ModifySnapshotCopyRetentionPeriodResponse
  ): zio.aws.redshift.model.ModifySnapshotCopyRetentionPeriodResponse.ReadOnly =
    new Wrapper(impl)
}
